@@ -2,6 +2,7 @@
 #  dpkg-cross.pl - Package with dpkg-cross common used functions
 #  Copyright (C) 2004  Nikita Youshchenko <yoush@cs.msu.su>
 #  Copyright (C) 2004  Raphael Bossek <bossekr@debian.org>
+#  Copyright (c) 2007  Neil Williams <codehelp@debian.org>
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -17,7 +18,7 @@
 #  along with this program; if not, write to the Free Software
 #  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#  $Id: dpkg-cross.pl,v 1.42 2006/10/15 11:17:32 yoush Exp $
+#  $Id: dpkg-cross.pl,v 1.46 2007-05-20 15:14:11 codehelp Exp $
 
 use File::Temp qw/tempfile tempdir/;
 
@@ -40,7 +41,7 @@ foreach my $var_ ( @intern_vars ) {
 }
 
 # Version of dpkg-cross environment.
-$DPKGCROSSVERSION = "1.29";
+$DPKGCROSSVERSION = "1.38";
 
 # Convertion table for Debian GNU/Linux architecture name (``$arch'') to GNU
 # type.
@@ -51,7 +52,8 @@ $DPKGCROSSVERSION = "1.29";
 	'alpha' => 'alpha-linux-gnu',
 	'm68k' => 'm68k-linux-gnu',
 	'arm' => 'arm-linux-gnu',
-	'armeb' => 'armeb-linux-gnu',
+	'armeb' => 'armeb-linux-gnueabi',
+	'armel' => 'arm-linux-gnueabi',
 	'powerpc' => 'powerpc-linux-gnu',
 	'ppc' => 'powerpc-linux-gnu',
 	'mips' => 'mips-linux-gnu',
@@ -208,6 +210,7 @@ sub read_config {
 			$package_ ||= "all";
 			$mode_ ||= "all";
 			$scope_ ||= "makeflags";
+			$current_package_ ||="";
 
 			# Store only data for current package and current mode, and
 			# for package "all" and mode "all".
@@ -222,6 +225,7 @@ sub read_config {
 			$package_ ||= "all";
 			$mode_ ||= "all";
 			$scope_ ||= "makeflags";
+			$current_package_ ||="";
 
 			if (($package_ eq "all" || $package_ eq $current_package_) && \
 				($mode_ eq "all" || $mode_ eq $current_mode_)) {
@@ -325,7 +329,7 @@ sub subst {
 	my @defined_vars_ = @_;
 	my ($name_, $newval_);
 
-	return if ref $$_valref_;	# skip "unset" values
+	return if ref $$valref_;	# skip "unset" values
 	
 	while ($$valref_ =~ /\$\((\w+)\)/) {
 		$name_ = $1;
@@ -609,6 +613,8 @@ sub convert_path ($) {
 		$path = "$crosslib/$'";
 	} elsif ($path =~ /^(\/usr(\/X11R6)?)?\/lib64\//) {
 		$path = "$crosslib64/$'";
+	} elsif ($path =~ /^\/usr\/\w+-\w+(-\w+(-\w+)?)?\//) {
+		# leave alone
 	} else {
 		$path =~ s/^\/usr/$crossdir/;
 	}
